<h1 align="center">歌词 LyricLib</h1>

<h3 align="center">歌词的处理库</h3>

<p align="center">
<img src="https://forthebadge.com/images/badges/built-with-love.svg">
<p>


[![][Bilibili: 金羿ELS]](https://space.bilibili.com/397369002/)
[![CodeStyle: black]](https://github.com/psf/black)
[![][python]](https://www.python.org/)
[![][license]](LICENSE)
[![][release]](../../releases)


简体中文🇨🇳 | [English🇬🇧](README_EN.md)


## 介绍🚀

LyricLib是一个简单的歌词处理库

欢迎加群：[861684859](https://jq.qq.com/?_wv=1027&k=hpeRxrYr)

## 文档📖

暂无

## 致谢🙏

非常感谢 [thecasttim](https://gitee.com/thecasttim) 的 [LrcParser](https://gitee.com/thecasttim/lrc-parser) 项目，为此项目提供了非常大的参考。可以说，本项目就是基于它进行了进一步的修改而开发的。


原作者 thecasttim 开发过程中参考了如下项目，此处将其展示出来。

+ python 根据歌词的时间（LRC文件），生成H5 audio按句播放器
    https://www.cnblogs.com/jifeng/p/12732226.html

+ https://github.com/Sorrow446/LRC/blob/master/lrc.py

+ 考虑了一行中有多个时间戳的情况
    https://github.com/greats3an/pyncm/blob/master/pyncm/utils/lrcparser.py   

+ https://github.com/doakey3/pylrc/blob/master/pylrc/parser.py

[Bilibili: 金羿ELS]: https://img.shields.io/badge/Bilibili-%E5%87%8C%E4%BA%91%E9%87%91%E7%BE%BF-00A1E7?style=for-the-badge
[CodeStyle: black]: https://img.shields.io/badge/code%20style-black-121110.svg?style=for-the-badge
[python]: https://img.shields.io/badge/python-3.6-AB70FF?style=for-the-badge
[release]: https://img.shields.io/github/v/release/EillesWan/Musicreater?style=for-the-badge
[license]: https://img.shields.io/badge/Licence-Apache-228B22?style=for-the-badge